@@ -337,7 +337,7 @@ def render_all(prompts: list[str], negative_prompts: Optional[list[str]], seeds:
     return grid_image
 
 
-if __name__ == '__main__':
+def main():
     parser = argparse.ArgumentParser(
         prog="grate",
         description="Generates a grid of images by running a set of prompts through different Stable Diffusion models.",
@@ -471,3 +471,6 @@ if __name__ == '__main__':
                local_files_only=args.local_files_only,
                save_partial_filename=args.output_path)
     print(f"grate saved to {args.output_path}")
+
+if __name__ == '__main__':
+    main()
